==> estateplat-common-1.2.3-20180208.064337-27-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfJjht.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 历史存量房经纪合同
 */
@Table(name = "ls_fcjy_clf_jjht")
public class LsFcjyClfJjht implements InsertVo {
    @Id
    private String jjhtid;//主键
    private String yjjhtid;//原经纪合同id
    private Long jjhtbh;//经纪合同编号
    private String mbid;//模版id
    private String wtlx;//委托类型
    private String wtly;//委托来源
    private Date wtsj;//委托时间
    private String wtdd;//委托地点
    private String hbh;//户编号
    private String fwsyqzh;//房屋所有权证号
    private String qlr;//权利人
    private String zjlx;//证件类型
    private String zjhm;//证件号码
    private String wtrdz;//委托人地址
    private String lxdh;//联系电话
    private String fdcjjjgbh;//房地产经纪结构编号
    private String fdcjjrbh;//房地产经纪人编号
    private String zt;//状态
    private String sfyx;//是否有效
    private String bz;//备注
    private Date wtqsrq;//委托起始日期
    private Date wtjsrq;//委托结束日期
    private String sfdj;//是否独家
    private String czr;//操作人
    private Date czsj;//操作时间
    private String czyy;//操作原因
    private String czlx;//操作类型

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getYjjhtid() {
        return yjjhtid;
    }

    public void setYjjhtid(String yjjhtid) {
        this.yjjhtid = yjjhtid;
    }

    public Long getJjhtbh() {
        return jjhtbh;
    }

    public void setJjhtbh(Long jjhtbh) {
        this.jjhtbh = jjhtbh;
    }

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getWtlx() {
        return wtlx;
    }

    public void setWtlx(String wtlx) {
        this.wtlx = wtlx;
    }

    public String getWtly() {
        return wtly;
    }

    public void setWtly(String wtly) {
        this.wtly = wtly;
    }

    public Date getWtsj() {
        return wtsj;
    }

    public void setWtsj(Date wtsj) {
        this.wtsj = wtsj;
    }

    public String getWtdd() {
        return wtdd;
    }

    public void setWtdd(String wtdd) {
        this.wtdd = wtdd;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwsyqzh() {
        return fwsyqzh;
    }

    public void setFwsyqzh(String fwsyqzh) {
        this.fwsyqzh = fwsyqzh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getZjhm() {
        return zjhm;
    }

    public void setZjhm(String zjhm) {
        this.zjhm = zjhm;
    }

    public String getWtrdz() {
        return wtrdz;
    }

    public void setWtrdz(String wtrdz) {
        this.wtrdz = wtrdz;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getFdcjjjgbh() {
        return fdcjjjgbh;
    }

    public void setFdcjjjgbh(String fdcjjjgbh) {
        this.fdcjjjgbh = fdcjjjgbh;
    }

    public String getFdcjjrbh() {
        return fdcjjrbh;
    }

    public void setFdcjjrbh(String fdcjjrbh) {
        this.fdcjjrbh = fdcjjrbh;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getWtqsrq() {
        return wtqsrq;
    }

    public void setWtqsrq(Date wtqsrq) {
        this.wtqsrq = wtqsrq;
    }

    public Date getWtjsrq() {
        return wtjsrq;
    }

    public void setWtjsrq(Date wtjsrq) {
        this.wtjsrq = wtjsrq;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCzyy() {
        return czyy;
    }

    public void setCzyy(String czyy) {
        this.czyy = czyy;
    }

    public String getCzlx() {
        return czlx;
    }

    public void setCzlx(String czlx) {
        this.czlx = czlx;
    }
}

==> estateplat-common-1.2.3-20180629.083220-134-sources.jar: cn/gtmap/estateplat/model/stockHouse/contract/LsFcjyClfJjht.java <==
package cn.gtmap.estateplat.model.stockHouse.contract;

import cn.gtmap.estateplat.model.server.core.InsertVo;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2018/1/16
 * @description 历史存量房经纪合同
 */
@Table(name = "ls_fcjy_clf_jjht")
public class LsFcjyClfJjht implements InsertVo {
    @Id
    private String jjhtid;//主键
    private String yjjhtid;//原经纪合同id
    private Long jjhtbh;//经纪合同编号
    private String mbid;//模版id
    private String wtlx;//委托类型
    private String wtly;//委托来源
    private Date wtsj;//委托时间
    private String wtdd;//委托地点
    private String hbh;//户编号
    private String fwsyqzh;//房屋所有权证号
    private String qlr;//权利人
    private String zjlx;//证件类型
    private String zjhm;//证件号码
    private String wtrdz;//委托人地址
    private String lxdh;//联系电话
    private String fdcjjjgbh;//房地产经纪结构编号
    private String fdcjjrbh;//房地产经纪人编号
    private String zt;//状态
    private String sfyx;//是否有效
    private String bz;//备注
    private Date wtqsrq;//委托起始日期
    private Date wtjsrq;//委托结束日期
    private String sfdj;//是否独家
    private String czr;//操作人
    private Date czsj;//操作时间
    private String czyy;//操作原因
    private String czlx;//操作类型
    private String htbz;//合同币种

    public String getJjhtid() {
        return jjhtid;
    }

    public void setJjhtid(String jjhtid) {
        this.jjhtid = jjhtid;
    }

    public String getYjjhtid() {
        return yjjhtid;
    }

    public void setYjjhtid(String yjjhtid) {
        this.yjjhtid = yjjhtid;
    }

    public Long getJjhtbh() {
        return jjhtbh;
    }

    public void setJjhtbh(Long jjhtbh) {
        this.jjhtbh = jjhtbh;
    }

    public String getMbid() {
        return mbid;
    }

    public void setMbid(String mbid) {
        this.mbid = mbid;
    }

    public String getWtlx() {
        return wtlx;
    }

    public void setWtlx(String wtlx) {
        this.wtlx = wtlx;
    }

    public String getWtly() {
        return wtly;
    }

    public void setWtly(String wtly) {
        this.wtly = wtly;
    }

    public Date getWtsj() {
        return wtsj;
    }

    public void setWtsj(Date wtsj) {
        this.wtsj = wtsj;
    }

    public String getWtdd() {
        return wtdd;
    }

    public void setWtdd(String wtdd) {
        this.wtdd = wtdd;
    }

    public String getHbh() {
        return hbh;
    }

    public void setHbh(String hbh) {
        this.hbh = hbh;
    }

    public String getFwsyqzh() {
        return fwsyqzh;
    }

    public void setFwsyqzh(String fwsyqzh) {
        this.fwsyqzh = fwsyqzh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getZjhm() {
        return zjhm;
    }

    public void setZjhm(String zjhm) {
        this.zjhm = zjhm;
    }

    public String getWtrdz() {
        return wtrdz;
    }

    public void setWtrdz(String wtrdz) {
        this.wtrdz = wtrdz;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getFdcjjjgbh() {
        return fdcjjjgbh;
    }

    public void setFdcjjjgbh(String fdcjjjgbh) {
        this.fdcjjjgbh = fdcjjjgbh;
    }

    public String getFdcjjrbh() {
        return fdcjjrbh;
    }

    public void setFdcjjrbh(String fdcjjrbh) {
        this.fdcjjrbh = fdcjjrbh;
    }

    public String getZt() {
        return zt;
    }

    public void setZt(String zt) {
        this.zt = zt;
    }

    public String getSfyx() {
        return sfyx;
    }

    public void setSfyx(String sfyx) {
        this.sfyx = sfyx;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getWtqsrq() {
        return wtqsrq;
    }

    public void setWtqsrq(Date wtqsrq) {
        this.wtqsrq = wtqsrq;
    }

    public Date getWtjsrq() {
        return wtjsrq;
    }

    public void setWtjsrq(Date wtjsrq) {
        this.wtjsrq = wtjsrq;
    }

    public String getSfdj() {
        return sfdj;
    }

    public void setSfdj(String sfdj) {
        this.sfdj = sfdj;
    }

    public String getCzr() {
        return czr;
    }

    public void setCzr(String czr) {
        this.czr = czr;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCzyy() {
        return czyy;
    }

    public void setCzyy(String czyy) {
        this.czyy = czyy;
    }

    public String getCzlx() {
        return czlx;
    }

    public void setCzlx(String czlx) {
        this.czlx = czlx;
    }

    public String getHtbz() {
        return htbz;
    }

    public void setHtbz(String htbz) {
        this.htbz = htbz;
    }
}
